// $Id: ivec_cmp.h,v 1.1 2017/03/20 03:53:22 leavens Exp $
#ifndef IVEC_CMP_H
#define IVEC_CMP_H 1
#include "ivec_len.h"

/* Does a lexicographical comparison of the elements of left and
   right, up to the first 0 in each, returning -1 if left is less than
   right, 0 if they are equal, and +1 if left is greater than right.
 */
/* requires: both target and src contain an element that is 0
   ensures: (result is 0 if ivec_len(left) == ivec_len(right)
                and for each i such that 0 <= i < ivec_len(left),
                                left[i] == right[i])
        and (result is -1 if there is some i such that
               0 <= i < ivec_len(left) and i <= ivec_len(right)
               and for each j such that 0 <= j < i, left[j] == right[j]
	       and (either left[i] < right[i] 
                       or (i == ivec_len(left)-1 
                           and ivec_len(left) < ivec_len(right))))
        and (result is +1 if there is some i such that
               0 <= i < ivec_len(left) and i <= ivec_len(right)
               and for each j such that 0 <= j < i, left[j] == right[j]
	       and (either left[i] > right[i] 
                       or (i == ivec_len(right)-1 
                           and ivec_len(left) > ivec_len(right))))
*/
extern int ivec_cmp(const int left[], const int right[]);
#endif
